@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Type
+from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -56,7 +56,7 @@ __all__ = ("ComprehendMedicalClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -75,7 +75,7 @@ class Exceptions:
 
 class ComprehendMedicalClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html)
     """
 
@@ -91,7 +91,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#can_paginate)
         """
 
@@ -101,7 +101,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with a medical entities detection job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_entities_detection_v2_job)
         """
 
@@ -111,7 +111,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with an InferICD10CM job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_icd10_cm_inference_job)
         """
 
@@ -120,7 +120,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with a protected health information (PHI)
         detection job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_phi_detection_job)
         """
 
@@ -130,7 +130,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with an InferRxNorm job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_rx_norm_inference_job)
         """
 
@@ -138,7 +138,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         The `DetectEntities` operation is deprecated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities)
         """
 
@@ -148,7 +148,7 @@ class ComprehendMedicalClient(BaseClient):
         specific information about them such as entity category, location, and
         confidence score on that information.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities_v2)
         """
 
@@ -157,21 +157,21 @@ class ComprehendMedicalClient(BaseClient):
         Inspects the clinical text for protected health information (PHI) entities and
         returns the entity category, location, and confidence score for each entity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_phi)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#generate_presigned_url)
         """
 
@@ -181,7 +181,7 @@ class ComprehendMedicalClient(BaseClient):
         and links those entities to normalized concept identifiers in the ICD-10-CM
         knowledge base from the Centers for Disease Control.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_icd10_cm)
         """
 
@@ -191,7 +191,7 @@ class ComprehendMedicalClient(BaseClient):
         to the normalized concept identifiers in the RxNorm database from the National
         Library of Medicine.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_rx_norm)
         """
 
@@ -205,7 +205,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of medical entity detection jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_entities_detection_v2_jobs)
         """
 
@@ -219,7 +219,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of InferICD10CM jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_icd10_cm_inference_jobs)
         """
 
@@ -234,7 +234,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of protected health information (PHI) detection jobs that you have
         submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_phi_detection_jobs)
         """
 
@@ -248,7 +248,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of InferRxNorm jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_rx_norm_inference_jobs)
         """
 
@@ -267,7 +267,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous medical entity detection job for a collection of
         documents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_entities_detection_v2_job)
         """
 
@@ -286,7 +286,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous job to detect medical conditions and link them to the
         ICD-10-CM ontology.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_icd10_cm_inference_job)
         """
 
@@ -304,7 +304,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Starts an asynchronous job to detect protected health information (PHI).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_phi_detection_job)
         """
 
@@ -323,7 +323,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous job to detect medication entities and link them to the
         RxNorm ontology.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_rx_norm_inference_job)
         """
 
@@ -333,7 +333,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops a medical entities detection job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_entities_detection_v2_job)
         """
 
@@ -341,7 +341,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops an InferICD10CM inference job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_icd10_cm_inference_job)
         """
 
@@ -349,7 +349,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops a protected health information (PHI) detection job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_phi_detection_job)
         """
 
@@ -357,6 +357,6 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops an InferRxNorm inference job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_rx_norm_inference_job)
         """
